@@ -3,10 +3,10 @@
  *  Module    : tin.h
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-03-07
+ *  Updated   : 2005-06-30
  *  Notes     : #include files, #defines & struct's
  *
- * Copyright (c) 1997-2005 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1997-2006 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -78,7 +78,7 @@
 
 #define N_(Str) Str
 
-#ifdef ENABLE_NLS
+#if defined(ENABLE_NLS) && !defined(__BUILD__)
 #	include <libintl.h>
 #	define _(Text)	gettext(Text)
 #else
@@ -87,7 +87,7 @@
 #	undef textdomain
 #	define textdomain(Domain) /* empty */
 #	define _(Text) Text
-#endif /* ENABLE_NLS */
+#endif /* ENABLE_NLS && !__BUILD__ */
 
 #ifndef LOCALEDIR
 #	define LOCALEDIR "/usr/share/locale"
@@ -592,7 +592,7 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 #	define PATH_ISPELL	"ispell"
 #endif /* !PATH_ISPELL */
 
-#ifndef PATH_METAMAIL	/* unly unset if !HAVE_METAMAIL */
+#ifndef PATH_METAMAIL	/* only unset if !HAVE_METAMAIL */
 #	define PATH_METAMAIL	"metamail"
 #endif /* !PATH_METAMAIL */
 #define METAMAIL_CMD		PATH_METAMAIL" -e -p -m \"tin\""
@@ -719,7 +719,7 @@ enum rc_state { RC_IGNORE, RC_CHECK, RC_UPGRADE, RC_DOWNGRADE, RC_ERROR };
 
 /*
  * URL related regexs:
- * add TELNET & WAIS (RFC 1738), IMAP (RFC 2192), NFS (RFC 2224)
+ * add TELNET (RFC 4248), WAIS (RFC 4156), IMAP (RFC 2192), NFS (RFC 2224)
  *     LDAP (RFC 2255), POP (RFC 2384)
  * add IPv6 (RFC 2732, RFC 2373) support
  */
@@ -1136,8 +1136,11 @@ enum {
 #define THREAD_REFS		2
 #define THREAD_BOTH		3
 #define THREAD_MULTI		4
+#define THREAD_PERC		5
 
-#define THREAD_MAX		THREAD_MULTI
+#define THREAD_MAX		THREAD_PERC
+
+#define THREAD_PERC_DEFAULT	75
 
 /*
  * Values for show_author
@@ -1293,7 +1296,9 @@ enum {
 /*
  * Assertion verifier
  */
-#undef assert
+#ifdef assert
+#	undef assert
+#endif /* assert */
 #ifdef CPP_DOES_EXPAND
 #	define assert(p)	if(! (p)) asfail(__FILE__, __LINE__, #p); else (void)0;
 #else
@@ -1356,9 +1361,6 @@ enum {
 /*
  * filter_type used in struct t_filter
  */
-#define FILTER_KILL		0
-#define FILTER_SELECT		1
-
 #define SCORE_MAX		10000
 
 #define FILTER_SUBJ_CASE_SENSITIVE		0
@@ -1458,7 +1460,7 @@ struct t_msgid {
  * struct t_article - article header
  *
  * article.thread:
- *  the next article in thread
+ * the next article in thread
  *	-1  (ART_UNTHREADED) article exists but is not (yet) threaded
  *	-2  (ART_EXPIRED) article has expired (wasn't found in search of spool
  *	    directory for the group)
@@ -1530,7 +1532,8 @@ struct t_attribute {
 	unsigned batch_save:1;			/* 0=none, 1=save -S/mail -M */
 	unsigned delete_tmp_files:1;		/* 0=leave, 1=delete */
 	unsigned show_only_unread:1;		/* 0=all, 1=only unread */
-	unsigned thread_arts:3;			/* 0=unthread, 1=subject, 2=refs, 3=both, 4=multipart*/
+	unsigned thread_arts:3;			/* 0=unthread, 1=subject, 2=refs, 3=both, 4=multipart, 5=percentage */
+	unsigned thread_perc:7;			/* percentage thrreading threshold */
 	unsigned show_author:2;			/* 0=none, 1=name, 2=addr, 3=both */
 	unsigned show_info:2;			/* 0=none, 1=lines, 2=score, 3=both */
 	unsigned sort_art_type:4;		/* 0=none, 1=subj descend, 2=subj ascend,
@@ -1643,10 +1646,10 @@ struct t_filter {
 	char *from;			/* From: line */
 	char *msgid;			/* Message-ID: line */
 	char lines_cmp;			/* Lines compare <> */
-	int  lines_num;			/* Lines: line */
+	int lines_num;			/* Lines: line */
 	char gnksa_cmp;			/* GNKSA compare <> */
-	int  gnksa_num;			/* GNKSA code */
-	int  score;			/* score to give if rule matches */
+	int gnksa_num;			/* GNKSA code */
+	int score;			/* score to give if rule matches */
 	char *xref;			/* groups in xref line */
 	time_t time;			/* expire time in seconds */
 	struct t_filter *next;		/* next rule valid in group */
