@@ -3,10 +3,10 @@
  *  Module    : cook.c
  *  Author    : J. Faultless
  *  Created   : 2000-03-08
- *  Updated   : 2004-11-04
+ *  Updated   : 2005-07-20
  *  Notes     : Split from page.c
  *
- * Copyright (c) 2000-2005 Jason Faultless <jason@altarstone.com>
+ * Copyright (c) 2000-2006 Jason Faultless <jason@altarstone.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -40,9 +40,7 @@
 #ifndef TCURSES_H
 #	include "tcurses.h"
 #endif /* !TCURSES_H */
-#ifndef RFC2046_H
-#	include "rfc2046.h"
-#endif /* !RFC2046_H */
+
 
 /*
  * We malloc() this many t_lineinfo's at a time
@@ -156,7 +154,7 @@ put_cooked(
 	char *p, *bufp, *buf;
 	int wrap_column;
 	int space;
-/*	static int overflow = 0; *//* TODO: we don't use it (anymore?) */
+/*	static int overflow = 0; */ /* TODO: we don't use it (anymore?) */
 	static int saved_flags = 0;
 	va_list ap;
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE)
@@ -172,7 +170,11 @@ put_cooked(
 	if (tinrc.wrap_column < 0)
 		wrap_column = ((tinrc.wrap_column > -cCOLS) ? cCOLS + tinrc.wrap_column : cCOLS);
 	else
+#if 1
 		wrap_column = ((tinrc.wrap_column > 0) ? tinrc.wrap_column : cCOLS);
+#else	/* never cut off long lines */
+		wrap_column = (((tinrc.wrap_column > 0) && (tinrc.wrap_column < cCOLS)) ? tinrc.wrap_column : cCOLS);
+#endif /* 1 */
 
 	p = bufp = buf;
 
@@ -507,7 +509,7 @@ process_text_body_part(
 		 * Skip output if we're hiding uue or the sig
 		 */
 		if (in_uue && hide_uue)
-			continue;						/* No further processing needed */
+			continue;	/* No further processing needed */
 
 		flags = in_sig ? C_SIG : C_BODY;
 
