@@ -3,10 +3,10 @@
  *  Module    : misc.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2005-02-12
+ *  Updated   : 2005-08-14
  *  Notes     :
  *
- * Copyright (c) 1991-2005 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2006 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,9 +50,6 @@
 #ifndef TIN_POLICY_H
 #	include "policy.h"
 #endif /* !TIN_POLICY_H */
-#ifndef RFC2046_H
-#	include "rfc2046.h"
-#endif /* !RFC2046_H */
 
 #if defined(HAVE_IDNA_H) && !defined(_IDNA_H)
 #	include <idna.h>
@@ -199,7 +196,7 @@ copy_fp(
  * try to backup filename as backupname. on success backupname has the same
  * permissions as filename.
  *
- * returncodes:
+ * return codes:
  * TRUE  = backup complete or source file was missing
  * FALSE = backup failed
  */
@@ -915,6 +912,7 @@ dir_name(
  *
  * TODO: why not cache the mailbox_name?
  */
+#define MAILDIR_NEW	"/new"
 t_bool
 mail_check(
 	void)
@@ -924,8 +922,35 @@ mail_check(
 
 	mailbox_name = get_val("MAIL", mailbox);
 
-	if (mailbox_name != 0 && stat(mailbox_name, &buf) >= 0 && buf.st_atime < buf.st_mtime && buf.st_size > 0)
-		return TRUE;
+	if (mailbox_name != 0 && stat(mailbox_name, &buf) >= 0) {
+		if ((int) (buf.st_mode & S_IFMT) == (int) S_IFDIR) { /* maildir setup */
+			DIR *dirp;
+			char *maildir_box;
+			struct dirent *dp;
+
+			maildir_box = my_malloc(strlen(mailbox_name) + strlen(MAILDIR_NEW) + 1);
+#ifdef VMS
+			joindir(maildir_box, mailbox_name, MAILDIR_NEW);
+#else
+			joinpath(maildir_box, mailbox_name, MAILDIR_NEW);
+#endif /* VMS */
+			if (!(dirp = opendir(maildir_box))) {
+				free(maildir_box);
+				return FALSE;
+			}
+			free(maildir_box);
+			while ((dp = readdir(dirp)) != NULL) {
+				if ((strcmp(dp->d_name, ".")) && (strcmp(dp->d_name, ".."))) {
+					closedir(dirp);
+					return TRUE;
+				}
+			}
+			closedir(dirp);
+		} else {
+			if (buf.st_atime < buf.st_mtime && buf.st_size > 0)
+				return TRUE;
+		}
+	}
 	return FALSE;
 }
 
@@ -1661,7 +1686,6 @@ strfpath(
 }
 
 
-
 /*
  * TODO: Properly explain this
  */
@@ -2029,15 +2053,12 @@ cleanup_tmp_files(
 #if 0
 	char acNovFile[PATH_LEN];
 
-	if (xover_cmd && !tinrc.cache_overview_files) {
+	if (nntp_caps.over_cmd && !tinrc.cache_overview_files) {
 		snprintf(acNovFile, sizeof(acNovFile), "%s%d.idx", TMPDIR, (int) process_id);
 		unlink(acNovFile);
 	}
 #endif /* 0 */
 
-	if (!tinrc.cache_overview_files)
-		unlink(local_newsgroups_file);
-
 	if (batch_mode)
 		unlink(lock_file);
 }
@@ -3397,7 +3418,15 @@ gnksa_split_from(
 		}
 	}
 
+	/*
+	 * if we allow <> as From: we must disallow <> as Mesage-ID,
+	 * see code in post.c:check_article_to_be_posted()
+	 */
+#if 0
+	if (!strchr(address, '@') && *address) /* check for From: without an @ but allow <> */
+#else
 	if (!strchr(address, '@')) /* check for From: without an @ */
+#endif /* 0 */
 		return GNKSA_ATSIGN_MISSING;
 
 	/* split successful */
